Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: include.preload.js

Issue 6269930580213760: Issue 309 - Don't use Shadow DOM in Chrome 32.0.1700 (Closed)
Patch Set: Fixed typo in comment Created April 17, 2014, 12:27 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include.preload.js
===================================================================
--- a/include.preload.js
+++ b/include.preload.js
@@ -26,9 +26,10 @@
var style = document.createElement("style");
style.setAttribute("type", "text/css");
- // Use Shadow DOM if available to don't mess with web pages
- // that rely on the order of their own <style> tags (#309)
- if ("webkitCreateShadowRoot" in document.documentElement)
+ // Use Shadow DOM if available to don't mess with web pages that
+ // rely on the order of their own <style> tags. However
+ // the <shadow> element is broken in Chrome 32.0.1700 (#309)
+ if ("webkitCreateShadowRoot" in document.documentElement && !/\bChrome\/32\.0\.1700\b/.test(navigator.userAgent))
{
var shadow = document.documentElement.webkitCreateShadowRoot();
shadow.appendChild(document.createElement("shadow"));
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld